@@ -688,7 +688,8 @@ protected:
   void paintEvent( QPaintEvent * );
   void fontChange( const QFont& );
   bool event(QEvent *event);
-
+  // For "Esc deselects all" functionality implemented in FSView.  
+  TreeMapItem *_pressed;
 private:
   TreeMapItemList diff(TreeMapItemList&, TreeMapItemList&);
   // returns true if selection changed
@@ -708,7 +709,7 @@ private:
   bool resizeAttr(int);
 
   TreeMapItem* _base;
-  TreeMapItem *_current, *_pressed, *_lastOver, *_oldCurrent;
+  TreeMapItem *_current, *_lastOver, *_oldCurrent;
   int _maxSelectDepth, _maxDrawingDepth;
 
   // attributes for field, per textNo
