@@ -529,7 +529,7 @@ QString PluginValidators::documentSource() const
 
 bool PluginValidators::doExternalValidationChecks()
 {
-  if (!parent()->inherits("KHTMLPart") && !parent()->inherits("WebKitPart"))
+  if (!parent()->inherits("KHTMLPart") && !parent()->inherits("KWebKitPart"))
   {
     const QString title = i18n("Cannot Validate Source");
     const QString text = i18n("You cannot validate anything except web pages with "
